"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.processStartUpHooks = void 0;
const dispatcher_1 = require("../../dispatcher");
const logger_1 = require("../../../logs/logger");
const checks_1 = require("../../checks");
const scm_1 = require("../../scm");
const processStartUpHooks = async (clientOpts, brokerClientId) => {
    var _a;
    try {
        let okToBoot = true;
        if (!clientOpts.config.brokerToken) {
            const brokerToken = clientOpts.config.brokerToken;
            // null, undefined, empty, etc.
            logger_1.log.error({ brokerToken }, '[MISSING_BROKER_TOKEN] BROKER_TOKEN is required to successfully identify itself to the server');
            okToBoot = false;
            const error = new ReferenceError('BROKER_TOKEN is required to successfully identify itself to the server');
            error['code'] = 'MISSING_BROKER_TOKEN';
            throw error;
        }
        if (!clientOpts.config.brokerServerUrl) {
            const brokerServerUrl = clientOpts.config.brokerServerUrl;
            // null, undefined, empty, etc.
            logger_1.log.error({ brokerServerUrl }, '[MISSING_BROKER_SERVER_URL] BROKER_SERVER_URL is required to connect to the broker server');
            okToBoot = false;
            const error = new ReferenceError('BROKER_SERVER_URL is required to connect to the broker server');
            error['code'] = 'MISSING_BROKER_SERVER_URL';
            throw error;
        }
        // Return early before processing anything further since the basics are not there....
        if (!okToBoot) {
            return { okToBoot };
        }
        if (!clientOpts.config.BROKER_CLIENT_URL) {
            const proto = !clientOpts.config.key && !clientOpts.config.cert ? 'http' : 'https';
            clientOpts.config.BROKER_CLIENT_URL = `${proto}://localhost:${clientOpts.port}`;
        }
        let serverId;
        if ((0, dispatcher_1.highAvailabilityModeEnabled)(clientOpts.config)) {
            serverId = await (0, dispatcher_1.getServerId)(clientOpts.config, brokerClientId);
            if (serverId === null) {
                logger_1.log.warn({}, 'could not receive server id from Broker Dispatcher');
                serverId = '';
            }
            else {
                logger_1.log.info({ serverId }, 'received server id');
                clientOpts.config.serverId = serverId;
            }
        }
        let preflightCheckResults = [];
        if ((0, checks_1.preflightChecksEnabled)(clientOpts.config)) {
            // wrap preflight checks execution into try-catch, so the broker client
            // will start anyway
            try {
                preflightCheckResults = await (0, checks_1.executePreflightChecks)(clientOpts.config);
            }
            catch (error) {
                logger_1.log.error({ error }, 'failed to execute preflight checks');
            }
        }
        if ((0, scm_1.commitSigningEnabled)(clientOpts.config)) {
            const commitSigningRules = (0, scm_1.commitSigningFilterRules)();
            (_a = clientOpts.filters.private) === null || _a === void 0 ? void 0 : _a.push(...commitSigningRules);
            logger_1.log.info({ enabled: true, rulesCount: commitSigningRules.length }, 'loading commit signing rules');
        }
        return {
            okToBoot,
            preflightCheckResults: preflightCheckResults.length
                ? preflightCheckResults
                : undefined,
        };
    }
    catch (error) {
        logger_1.log.error({ error }, 'Error processing startup hooks');
        return { okToBoot: false };
    }
};
exports.processStartUpHooks = processStartUpHooks;
//# sourceMappingURL=processHooks.js.map